#ifndef CONSTANTS
#define CONSTANTS

//Bowell 1989 HG simple constants
#define HG_SIMPLE_A1 3.33
#define HG_SIMPLE_A2 1.87
#define HG_SIMPLE_B1 0.63
#define HG_SIMPLE_B2 1.22

//Bowell 1989 HG constants
#define HG_A1 3.332
#define HG_A2 1.862
#define HG_B1 0.631
#define HG_B2 1.218
#define HG_C1 0.986
#define HG_C2 0.238



#endif